package jp.co.intra_mart.sample.im_workflow.tsfw.app.purchase;

import java.io.IOException;

import javax.inject.Inject;

import jp.co.intra_mart.foundation.context.Contexts;
import jp.co.intra_mart.foundation.context.model.ClientContext;
import jp.co.intra_mart.foundation.multi_device.client_type.ClientTypeSwitcher;
import jp.co.intra_mart.foundation.security.exception.AccessSecurityException;
import jp.co.intra_mart.foundation.security.message.MessageManager;
import jp.co.intra_mart.foundation.service.client.information.Identifier;
import jp.co.intra_mart.foundation.ui.page.Transfer.Message;
import jp.co.intra_mart.foundation.workflow.code.PageType;
import jp.co.intra_mart.framework.extension.spring.web.servlet.view.TransferView;
import jp.co.intra_mart.sample.im_workflow.tsfw.domain.model.SampleImwTPurchase;
import jp.co.intra_mart.sample.im_workflow.tsfw.domain.repository.SampleImwTPurchaseRepository;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

@Controller
@RequestMapping("sample/im_workflow/tsfw/app/purchase")
public class PurchaseController {

    @Inject
    SampleImwTPurchaseRepository repository;

    /**
     * 申請画面表示処理.
     * @param model モデル
     * @return 遷移先
     * @throws AccessSecurityException
     * @throws IOException
     */
    @RequestMapping(value = "apply")
    public final String apply(final Model model, final PurchaseForm purchaseForm) throws AccessSecurityException, IOException {

        if (PageType.pageTyp_App.toString().equals(purchaseForm.getImwPageType())) {
            // 申請
            String userDataId = "";
            final Identifier identifier = new Identifier();
            userDataId = identifier.get();

            purchaseForm.setImwUserDataId(userDataId);
        } else if (PageType.pageTyp_UnApp.toString().equals(purchaseForm.getImwPageType())) {
            // 起票
        } else {
            // 一時保存 or 再申請
            final SampleImwTPurchase matterData = repository.select(purchaseForm.getImwUserDataId());
            if (matterData == null) {
                final Message message = new Message();
                message.setTitle(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
                message.setMessage(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
                final String[] details = { MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.005") };
                message.setDetails(details);
                model.addAttribute(TransferView.MESSAGE, message);
                return TransferView.VIEW_NAME_ERROR;
            }

            purchaseForm.setItem_name(matterData.getItemName());
            purchaseForm.setItem_amount(matterData.getItemAmount());
            purchaseForm.setItem_price(matterData.getItemPrice());
            purchaseForm.setItem_comment(matterData.getItemComment());

        }

        model.addAttribute(purchaseForm);

        return "sample/im_workflow/tsfw/app/purchase/apply.jsp";
    }

    /**
     * 処理画面表示処理.
     * @param model モデル
     * @return 遷移先
     * @throws AccessSecurityException
     */
    @RequestMapping(value = "approve")
    public final String approve(final Model model, final PurchaseForm purchaseForm) throws AccessSecurityException {
        final SampleImwTPurchase matterData = repository.select(purchaseForm.getImwUserDataId());

        if (matterData == null) {
            final Message message = new Message();
            message.setTitle(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            message.setMessage(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            final String[] details = { MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.005") };
            message.setDetails(details);
            model.addAttribute(TransferView.MESSAGE, message);
            return TransferView.VIEW_NAME_ERROR;
        }

        purchaseForm.setItem_name(matterData.getItemName());
        purchaseForm.setItem_amount(matterData.getItemAmount());
        purchaseForm.setItem_price(matterData.getItemPrice());
        purchaseForm.setItem_total(matterData.getItemTotal());
        purchaseForm.setItem_comment(matterData.getItemComment());

        model.addAttribute(purchaseForm);
        return "sample/im_workflow/tsfw/app/purchase/approve.jsp";
    }

    /**
     * 確認画面表示処理.
     * @param model モデル
     * @return 遷移先
     * @throws AccessSecurityException
     */
    @RequestMapping(value = "confirm")
    public final String confirm(final Model model, final PurchaseForm purchaseForm) throws AccessSecurityException {
        final SampleImwTPurchase matterData = repository.select(purchaseForm.getImwUserDataId());

        if (matterData == null) {
            final Message message = new Message();
            message.setTitle(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            message.setMessage(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            final String[] details = { MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.005") };
            message.setDetails(details);
            model.addAttribute(TransferView.MESSAGE, message);
            return TransferView.VIEW_NAME_ERROR;
        }

        purchaseForm.setItem_name(matterData.getItemName());
        purchaseForm.setItem_amount(matterData.getItemAmount());
        purchaseForm.setItem_price(matterData.getItemPrice());
        purchaseForm.setItem_total(matterData.getItemTotal());
        purchaseForm.setItem_comment(matterData.getItemComment());

        model.addAttribute(purchaseForm);
        return "sample/im_workflow/tsfw/app/purchase/confirm.jsp";
    }

    /**
     * 詳細画面表示処理.
     * @param model モデル
     * @return 遷移先
     * @throws AccessSecurityException
     */
    @RequestMapping(value = "detail")
    public final String detail(final Model model, final PurchaseForm purchaseForm) throws AccessSecurityException {
        final SampleImwTPurchase matterData = repository.select(purchaseForm.getImwUserDataId());

        if (matterData == null) {
            final Message message = new Message();
            message.setTitle(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            message.setMessage(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
            final String[] details = { MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.005") };
            message.setDetails(details);
            model.addAttribute(TransferView.MESSAGE, message);
            return TransferView.VIEW_NAME_ERROR;
        }

        purchaseForm.setItem_name(matterData.getItemName());
        purchaseForm.setItem_amount(matterData.getItemAmount());
        purchaseForm.setItem_price(matterData.getItemPrice());
        purchaseForm.setItem_total(matterData.getItemTotal());
        purchaseForm.setItem_comment(matterData.getItemComment());

        model.addAttribute(purchaseForm);

        // ショートカットURLからのアクセスかどうかを判定します。
        model.addAttribute("imwShortCutAccess", "1".equals(purchaseForm.getImwShortCutFlag()));

        // クライアントタイプがスマートフォンの場合は、PCに切り替えます。
        final ClientContext context = Contexts.get(ClientContext.class);
        if ("sp".equals(context.getClientTypeId())) {
            ClientTypeSwitcher.oneTimeSwitchTo("pc");
            model.addAttribute("isSmartPhone", true);
        }

        return "sample/im_workflow/tsfw/app/purchase/detail.jsp";
    }

    /**
     * エラーハンドリング処理.
     * @param 例外クラス e
     * @return ModelAndView
     * @throws AccessSecurityException
     */
    @ExceptionHandler(Exception.class)
    public ModelAndView ExceptionHandler(final Exception e) throws AccessSecurityException {
        final Message message = new Message();
        message.setTitle(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
        message.setMessage(MessageManager.getInstance().getMessage("SAMPLE.IMW.ERR.004"));
        final String[] details = { MessageManager.getInstance().getMessage("SAMPLE.IMW.TSFW.ERR.001") };
        message.setDetails(details);
        return new ModelAndView(TransferView.VIEW_NAME_ERROR).addObject(TransferView.MESSAGE, message);
    }
}
